@@ -21,6 +21,7 @@ import (
 	"bufio"
 	"flag"
 	"fmt"
+	"io"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -157,6 +158,7 @@ func (l *Ldconfig) UpdateLDCache() error {
 		return fmt.Errorf("failed to write %s drop-in: %w", ldsoconfdFilenamePattern, err)
 	}
 
+	systemSearchPaths := l.getSystemSearchPaths()
 	// In most cases, the hook will be executing a host ldconfig that may be configured widely
 	// differently from what the container image expects.
 	// The common case is Debian-like (e.g. Debian, Ubuntu) vs non-Debian-like (e.g. RHEL, Fedora).
@@ -165,10 +167,15 @@ func (l *Ldconfig) UpdateLDCache() error {
 	// paths to a drop-in conf file that is likely to be last in lexicographic order. Entries in the
 	// top-level ld.so.conf file may be processed after this drop-in, but this hook does not modify
 	// the top-level file if it exists.
-	if err := createLdsoconfdFile(defaultLdsoconfdDir, ldsoconfdSystemDirsFilenamePattern, l.getSystemSearchPaths()...); err != nil {
+	if err := createLdsoconfdFile(defaultLdsoconfdDir, ldsoconfdSystemDirsFilenamePattern, systemSearchPaths...); err != nil {
 		return fmt.Errorf("failed to write %s drop-in: %w", ldsoconfdSystemDirsFilenamePattern, err)
 	}
 
+	// Also output the folders to the alpine .path file as required.
+	if err := createMuslPathFileIfRequired(append(filteredDirectories, systemSearchPaths...)...); err != nil {
+		return fmt.Errorf("failed to update .path file for musl: %w", err)
+	}
+
 	return SafeExec(ldconfigPath, args, nil)
 }
 
@@ -235,16 +242,8 @@ func createLdsoconfdFile(ldsoconfdDir, pattern string, dirs ...string) error {
 		_ = configFile.Close()
 	}()
 
-	added := make(map[string]bool)
-	for _, dir := range dirs {
-		if added[dir] {
-			continue
-		}
-		_, err := fmt.Fprintf(configFile, "%s\n", dir)
-		if err != nil {
-			return fmt.Errorf("failed to update config file: %w", err)
-		}
-		added[dir] = true
+	if err := outputListToFile(configFile, dirs...); err != nil {
+		return err
 	}
 
 	// The created file needs to be world readable for the cases where the container is run as a non-root user.
@@ -255,6 +254,21 @@ func createLdsoconfdFile(ldsoconfdDir, pattern string, dirs ...string) error {
 	return nil
 }
 
+func outputListToFile(w io.Writer, dirs ...string) error {
+	added := make(map[string]bool)
+	for _, dir := range dirs {
+		if added[dir] {
+			continue
+		}
+		_, err := fmt.Fprintf(w, "%s\n", dir)
+		if err != nil {
+			return fmt.Errorf("failed to update config file: %w", err)
+		}
+		added[dir] = true
+	}
+	return nil
+}
+
 // ensureLdsoconfFile creates a "standard" top-level ld.so.conf file if none exists.
 //
 // The created file will contain a single include statement for "`ldsoconfdDir`/*.conf".
@@ -349,6 +363,45 @@ func processLdsoconfFile(ldsoconfFilename string) ([]string, []string, error) {
 	return directories, includedFilenames, nil
 }
 
+// createMuslPathFileIfRequired creates a musl .path file that allows libraries
+// from the specified directories to be discovered on the system.
+// This is required because systems that use musl do not rely on the ldcache to
+// discover libraries.
+func createMuslPathFileIfRequired(dirs ...string) error {
+	if len(dirs) == 0 || !isMusl() {
+		return nil
+	}
+
+	var pathFileName string
+	switch runtime.GOARCH {
+	case "amd64":
+		pathFileName = "/etc/ld-musl-x86_64.path"
+	case "arm64":
+		pathFileName = "/etc/ld-musl-aarch64.path"
+	}
+
+	pathFile, err := os.OpenFile(pathFileName, os.O_CREATE|os.O_APPEND|os.O_RDWR, 0644)
+	if err != nil {
+		return fmt.Errorf("could not open .path file: %w", err)
+	}
+	defer func() {
+		_ = pathFile.Close()
+	}()
+
+	return outputListToFile(pathFile, dirs...)
+}
+
+// isMusl checks whether the container is running musl instead of glibc.
+// Note that for the time being we only check whether `/etc/alpine-release` is
+// present in the container.
+func isMusl() bool {
+	info, err := os.Stat("/etc/alpine-release")
+	if err != nil {
+		return false
+	}
+	return !info.IsDir()
+}
+
 // isDebianLike returns true if a Debian-like distribution is detected.
 // Debian-like distributions include Debian and Ubuntu, whereas non-Debian-like
 // distributions include RHEL and Fedora.
